==> PanalogFree_JUPITERr1p1_20220831_FreeBSD10x_amd64.tar.gz: usr/logd/www/secure/mailcious_download.php <==
<?php
session_start();
set_time_limit(0);
$doc = $_SERVER["DOCUMENT_ROOT"];
include($doc."/common.php");
if (!chksession()) {
	echo '<script type="text/javascript">parent.location.href="../index.php";</script>';
	exit;
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" content="no-cache">
<title><?=VERSION?></title>
<link type="text/css" rel="stylesheet" href="../css/common.css" />
<script type="text/javascript" src="../js/jquery.min.js"></script>
<script type="text/javascript" src="../js/common.js"></script>
<script type="text/javascript">
</script>
</head>
<body class="als-body">
<div class="outer">
	<div class="als-nav-header">
		<ul>
			<li><a href="mailcious_host.php">访问排名</a></li>
			<li><a href="mailcious_user.php">用户排名</a></li>
			<?php
				 $user = $_SESSION["palog_username"];
				 if( $user == "admin"){
					 
					echo "<li ><a href='mailcious_download.php'>更新数据</a></li>";
				 }	
			?>
		</ul>
	</div>
	<div class="als-content">
<?php
	
exec("cat /usr/logd/bin/mailcious/stat.log", $out, $ret);
$conf = $out[0];
$tmp_arr = explode("=",$conf);
$mc_count = $tmp_arr[1];

$conf1 = array();
$lastupdate = "0";
if (file_exists("/usr/logd/bin/mailcious/version.inf")) {
	$conf1 = file_get_contents("/usr/logd/bin/mailcious/version.inf");
	$tmp_arr1 = explode("=", $conf1);
	$lastupdate = date("Y/m/d H:i:s", $tmp_arr1[1]);
}

	$checked = "";
	//$mc_count = 0;
	//$lastupdate = 0;
	$cmd = PANALOGEYE." mailcious2 stat";
	exec($cmd, $out, $ret);
	if (is_array($out) && count($out) > 0) {
		foreach($out as $val) {
			$ds = explode('=', trim($val));
			switch($ds[0]) {
			case "enable":
				if ($ds[1] == "1")
					$checked = "checked";
				break;
			}
		}
	}

	$mailcious_download_auto = getconfig("mailcious_download_auto");
	if ($mailcious_download_auto != 0)
		$mailcious_download_auto_checked = "checked";
	
	
	
	
	$mailcious_all_checked = "";
	$mailcious_dic_checked = "";
	$arr1 = file("/usr/logd/bin/log.conf");
	foreach($arr1 as $val){
		$arr2 = explode("=",trim($val));
		if($arr2[0] == "mailcious_type"){
			$type = $arr2[1];
			if($type == "all")
				$mailcious_all_checked = "checked";
			else
				$mailcious_dic_checked = "checked";
		}
		
	}
	
	
	
	
?>

		<div style="margin-top:20px;">
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<div class="layui-form-item">
						<div class="layui-input-inline" style="margin-left:20px;">
							<input type="checkbox" name="enable" lay-skin="switch" <?=$checked?> lay-text="ON|OFF" lay-filter="mailcious-enable">
						</div>
					</div>
				</form>
			</div>
			<div style="float:left; width:200px; background:#f5f5f5; border-radius:3px;">
				<div style="padding:5px;">库记录数</div>
				<div style="padding:5px 20px; font-size:14px; color:#e39507; font-weight:bold;"><?=$mc_count?></div>
			</div>
			<div style="float:left; width:200px; background:#f5f5f5; border-radius:3px; margin-left:40px;">
				<div style="padding:5px;">库更新时间</div>
				<div style="padding:5px 20px; font-size:14px; color:#e39507; font-weight:bold;"><?=$lastupdate?></div>
			</div>
			<div style="clear:both;"></div>
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>本地上传</legend>
			</fieldset>
		</div>
		<div style="padding:20px 0 20px 20px;;">
			<form enctype="multipart/form-data" method="post" action="handle.php" target="system-upgrade-frame" onsubmit="return iscorrect()">
				<table width="100%">
					<tr>
						<td colspan="2" class="font-fileupload" align="left">
							<input type="file" name="mail_upload" id="mail_upload" style="width:500px" />
							<input type="submit" value="上传威胁库" style="height:22px;" />
							(从本地上传的文件名为panalog.db)
							<input type="hidden" value="mailcious_upload" name="action" style="height:22px;" />
						</td>
						
					</tr>
				</table>
			</form>
			<iframe src="about:blank" name="system-upgrade-frame" id="system-upgrade-frame" style="display:none;" frameborder=0></iframe>
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>网络下载</legend>
			</fieldset>
		</div>
		<div style="padding:20px 0 10px 0px;">
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<div class="layui-form-item">
						<div class="layui-input-inline" style="margin-left:20px;">
							<input type="checkbox" name="mailcious_download_enable" lay-skin="switch" <?=$mailcious_download_auto_checked?> lay-text="ON|OFF" lay-filter="mailcious-download-enable">
						</div>
					</div>
				</form>
			</div>
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<!--<select id="mailcious_type" lay-verify="">
					  <option value="all" selected>所有情报</option>
					  <option value="digiccy">挖矿情报</option>
					</select>
					-->
					<input type="radio" name="mailcious_type" value="all" title="所有情报" <?=$mailcious_all_checked?> lay-filter="mailcious_type">
					<input type="radio" name="mailcious_type" value="digiccy" title="挖矿情报"  <?=$mailcious_dic_checked?>   lay-filter="mailcious_type">
				</form>
			</div>
			<input type="button" id="mail-down-start-btn" value="立即更新新的恶意库" class="layui-btn layui-btn-normal layui-btn-xs">
			<input type="button" id="mail-down-stop-btn" value="停止下载" class="layui-btn layui-btn-normal layui-btn-xs">
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>下载记录</legend>
			</fieldset>
		</div>
		<div class="topapp-list-table">
			<table style="width:100%;" id="filelist">
				<tr>
					<th class="txt-center" width="50px">序号</th>
					<th class="txt-left">文件名称</th>
					<th class="txt-left">文件大小/Byte</th>
					<th class="txt-left">创建时间</th>
					<th class="txt-left">下载速率</th>
				</tr>
				<tr>
					<td colspan="2" align="center">暂无下载记录</td>
				</tr>
			</table>
		</div>
	</div>
</div>
<script type="text/javascript" src="../layui/layui.js"></script>
<script type="text/javascript">
layui.use(['layer', 'form'], function(){
	layer = layui.layer ,form = layui.form;
	
	mailcious_list();
	form.on('switch(mailcious-enable)', function(data){
		if (data.elem.checked == false) {
			$("[name='enable']").eq(0).removeAttr("checked");
			mailcious_disable();
		}
		else {
			mailcious_enable();
			$("[name='enable']").eq(0).attr("checked", true);
		}
		form.render();
	});

	form.on('switch(mailcious-download-enable)', function(data){
		if (data.elem.checked == false) {
			$("[name='enable']").eq(0).removeAttr("checked");
			mailcious_download_disable();
		}
		else {
			mailcious_download_enable();
			$("[name='enable']").eq(0).attr("checked", true);
		}
		form.render();
	});
	
	
	form.on('radio(mailcious_type)', function(data){
		mailcious_type(data.value);
	});
	
});

function iscorrect()
{
	var path = $("#mail_upload").val();
	if (path == "") {
		alert("请选择威胁情报库路径");
		return false;
	}

	if (!confirm("确定要上传文件吗？"))
		return false;

	return true;
}

function mailcious_enable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_enable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_disable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_disable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_type(type)
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_type',type:type},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_download_enable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_download_enable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_download_disable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_download_disable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

var _lastbyte = 0;
var sec = 2;
var _t = setInterval(mailcious_list, sec * 1000);

$("#mail-down-start-btn").click(mailcious_download);
$("#mail-down-stop-btn").click(mailcious_stop);
function mailcious_stop()
{
	layer.confirm("确定要停止更新恶意库吗？", {btn:['确定', '取消']}, function(index) {
		$.ajax({
			url:'handle.php',
			type: 'post',
			data: {action: 'mailcious_stop'},
			success:function(json) {
				layer.msg("已停止下载");
			}
		})
	})
}

function mailcious_download()
{
	//var mailcious_type = $("input[name='mailcious_type']:checked").val();
	layer.confirm("确定要更新恶意库吗？", {btn:['确定', '取消']}, function(index) {
		layer.msg("开始下载，请耐心等待...");
		$.ajax({
			url:'handle.php',
			type: 'post',
			data: {action: 'mailcious_download'},
			dataType: 'json',
			success:function(json) {
				if (json.yn == "no")
					layer.msg(json.str);
			}
		})
	})
}

function mailcious_list()
{
	//var loading = layer.load(0, {shade: false, time: 0});

	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_list'},
		dataType: 'json',
		success:function(json) {
			//layer.close(loading);
			data_update(json);
		}
	})
}

function data_update(json)
{
	var down = 0;

	var list = document.getElementById("filelist");
	while (list.rows.length > 1)
		list.deleteRow(1);
	for (i = 0; i < json.length; i++) {
		r = json[i];

		trbg = '';
		if (i % 2 == 1)
			trbg = 'log-table-tr-toggle-bgcolor-curr';

		var bps = 0;
		var istatus = '<img src="../img/10.png" width="16px" />';
		if (r.name.indexOf("tar.gz") != -1) {
			if (_lastbyte == 0)
				_lastbyte = r.size;
			bps = (r.size - _lastbyte) * 8 / sec;
			_lastbyte = r.size;
			down = 1;
			istatus = "<strong>正在下载 </strong>";
		}

		var pos = 0;
		obj = list.insertRow(-1);
		obj.setAttribute("class", trbg);

		col = obj.insertCell(pos++);
		col.setAttribute("align", "center");
		col.innerHTML = i+1;

		col = obj.insertCell(pos++);
		col.innerHTML = istatus + ' ' + r.name;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = r.size;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = r.atime;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = bps;
	}
}
</script>
</body>
</html>

==> PanalogFree_JUPITERr1p1_20220927_FreeBSD10x_amd64.tar.gz: usr/logd/www/secure/mailcious_download.php <==
<?php
session_start();
set_time_limit(0);
$doc = $_SERVER["DOCUMENT_ROOT"];
include($doc."/common.php");
if (!chksession()) {
	echo '<script type="text/javascript">parent.location.href="../index.php";</script>';
	exit;
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" content="no-cache">
<title><?=VERSION?></title>
<link type="text/css" rel="stylesheet" href="../css/common.css" />
<script type="text/javascript" src="../js/jquery.min.js"></script>
<script type="text/javascript" src="../js/common.js"></script>
<script type="text/javascript">
</script>
</head>
<body class="als-body">
<div class="outer">
	<div class="als-nav-header">
		<ul>
			<li><a href="mailcious_host.php">访问排名</a></li>
			<li><a href="mailcious_user.php">用户排名</a></li>
			<?php
				 $user = $_SESSION["palog_username"];
				 if( $user == "admin"){
					 
					echo "<li class='active'><a href='mailcious_download.php'>更新数据</a></li>";
				 }	
			?>
		</ul>
	</div>
	<div class="als-content">
<?php
	
exec("cat /usr/logd/bin/mailcious/stat.log", $out, $ret);
$conf = $out[0];
$tmp_arr = explode("=",$conf);
$mc_count = $tmp_arr[1];

$conf1 = array();
$lastupdate = "0";
if (file_exists("/usr/logd/bin/mailcious/version.inf")) {
	$conf1 = file_get_contents("/usr/logd/bin/mailcious/version.inf");
	$tmp_arr1 = explode("=", $conf1);
	$lastupdate = date("Y/m/d H:i:s", $tmp_arr1[1]);
}

	$checked = "";
	//$mc_count = 0;
	//$lastupdate = 0;
	$cmd = PANALOGEYE." mailcious2 stat";
	exec($cmd, $out, $ret);
	if (is_array($out) && count($out) > 0) {
		foreach($out as $val) {
			$ds = explode('=', trim($val));
			switch($ds[0]) {
			case "enable":
				if ($ds[1] == "1")
					$checked = "checked";
				break;
			}
		}
	}

	$mailcious_download_auto = getconfig("mailcious_download_auto");
	if ($mailcious_download_auto != 0)
		$mailcious_download_auto_checked = "checked";
	
	
	
	
	$mailcious_all_checked = "";
	$mailcious_dic_checked = "";
	$arr1 = file("/usr/logd/bin/log.conf");
	foreach($arr1 as $val){
		$arr2 = explode("=",trim($val));
		if($arr2[0] == "mailcious_type"){
			$type = $arr2[1];
			if($type == "all")
				$mailcious_all_checked = "checked";
			else
				$mailcious_dic_checked = "checked";
		}
		
	}
	
	
	
	
?>

		<div style="margin-top:20px;">
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<div class="layui-form-item">
						<div class="layui-input-inline" style="margin-left:20px;">
							<input type="checkbox" name="enable" lay-skin="switch" <?=$checked?> lay-text="ON|OFF" lay-filter="mailcious-enable">
						</div>
					</div>
				</form>
			</div>
			<div style="float:left; width:200px; background:#f5f5f5; border-radius:3px;">
				<div style="padding:5px;">库记录数</div>
				<div style="padding:5px 20px; font-size:14px; color:#e39507; font-weight:bold;"><?=$mc_count?></div>
			</div>
			<div style="float:left; width:200px; background:#f5f5f5; border-radius:3px; margin-left:40px;">
				<div style="padding:5px;">库更新时间</div>
				<div style="padding:5px 20px; font-size:14px; color:#e39507; font-weight:bold;"><?=$lastupdate?></div>
			</div>
			<div style="clear:both;"></div>
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>本地上传</legend>
			</fieldset>
		</div>
		<div style="padding:20px 0 20px 20px;;">
			<form enctype="multipart/form-data" method="post" action="handle.php" target="system-upgrade-frame" onsubmit="return iscorrect()">
				<table width="100%">
					<tr>
						<td colspan="2" class="font-fileupload" align="left">
							<input type="file" name="mail_upload" id="mail_upload" style="width:500px" />
							<input type="submit" value="上传威胁库" style="height:22px;" />
							(从本地上传的文件名为panalog.db)
							<input type="hidden" value="mailcious_upload" name="action" style="height:22px;" />
						</td>
						
					</tr>
				</table>
			</form>
			<iframe src="about:blank" name="system-upgrade-frame" id="system-upgrade-frame" style="display:none;" frameborder=0></iframe>
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>网络下载</legend>
			</fieldset>
		</div>
		<div style="padding:20px 0 10px 0px;">
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<div class="layui-form-item">
						<div class="layui-input-inline" style="margin-left:20px;">
							<input type="checkbox" name="mailcious_download_enable" lay-skin="switch" <?=$mailcious_download_auto_checked?> lay-text="ON|OFF" lay-filter="mailcious-download-enable">
						</div>
					</div>
				</form>
			</div>
			<div style="float:left; width:200px;">
				<form class="layui-form" action="">
					<!--<select id="mailcious_type" lay-verify="">
					  <option value="all" selected>所有情报</option>
					  <option value="digiccy">挖矿情报</option>
					</select>
					-->
					<input type="radio" name="mailcious_type" value="all" title="所有情报" <?=$mailcious_all_checked?> lay-filter="mailcious_type">
					<input type="radio" name="mailcious_type" value="digiccy" title="挖矿情报"  <?=$mailcious_dic_checked?>   lay-filter="mailcious_type">
				</form>
			</div>
			<input type="button" id="mail-down-start-btn" value="立即更新新的恶意库" class="layui-btn layui-btn-normal layui-btn-xs">
			<input type="button" id="mail-down-stop-btn" value="停止下载" class="layui-btn layui-btn-normal layui-btn-xs">
		</div>
		<div>
			<fieldset class="layui-elem-field layui-field-title" style="margin-top: 20px;">
				<legend>下载记录</legend>
			</fieldset>
		</div>
		<div class="topapp-list-table">
			<table style="width:100%;" id="filelist">
				<tr>
					<th class="txt-center" width="50px">序号</th>
					<th class="txt-left">文件名称</th>
					<th class="txt-left">文件大小/Byte</th>
					<th class="txt-left">下载时间</th>
					<th class="txt-left">下载速率</th>
				</tr>
				<tr>
					<td colspan="2" align="center">暂无下载记录</td>
				</tr>
			</table>
		</div>
	</div>
</div>
<script type="text/javascript" src="../layui/layui.js"></script>
<script type="text/javascript">
layui.use(['layer', 'form'], function(){
	layer = layui.layer ,form = layui.form;
	
	mailcious_list();
	form.on('switch(mailcious-enable)', function(data){
		if (data.elem.checked == false) {
			$("[name='enable']").eq(0).removeAttr("checked");
			mailcious_disable();
		}
		else {
			mailcious_enable();
			$("[name='enable']").eq(0).attr("checked", true);
		}
		form.render();
	});

	form.on('switch(mailcious-download-enable)', function(data){
		if (data.elem.checked == false) {
			$("[name='enable']").eq(0).removeAttr("checked");
			mailcious_download_disable();
		}
		else {
			mailcious_download_enable();
			$("[name='enable']").eq(0).attr("checked", true);
		}
		form.render();
	});
	
	
	form.on('radio(mailcious_type)', function(data){
		mailcious_type(data.value);
	});
	
});

function iscorrect()
{
	var path = $("#mail_upload").val();
	if (path == "") {
		alert("请选择威胁情报库路径");
		return false;
	}

	if (!confirm("确定要上传文件吗？"))
		return false;

	return true;
}

function mailcious_enable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_enable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_disable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_disable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_type(type)
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_type',type:type},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_download_enable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_download_enable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

function mailcious_download_disable()
{
	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_download_disable'},
		success:function(json) {
			layer.msg("操作成功");
		}
	})
}

var _lastbyte = 0;
var sec = 2;
var _t = setInterval(mailcious_list, sec * 1000);

$("#mail-down-start-btn").click(mailcious_download);
$("#mail-down-stop-btn").click(mailcious_stop);
function mailcious_stop()
{
	layer.confirm("确定要停止更新恶意库吗？", {btn:['确定', '取消']}, function(index) {
		$.ajax({
			url:'handle.php',
			type: 'post',
			data: {action: 'mailcious_stop'},
			success:function(json) {
				layer.msg("已停止下载");
			}
		})
	})
}

function mailcious_download()
{
	//var mailcious_type = $("input[name='mailcious_type']:checked").val();
	layer.confirm("确定要更新恶意库吗？", {btn:['确定', '取消']}, function(index) {
		layer.msg("开始下载，请耐心等待...");
		$.ajax({
			url:'handle.php',
			type: 'post',
			data: {action: 'mailcious_download'},
			dataType: 'json',
			success:function(json) {
				if (json.yn == "no")
					layer.msg(json.str);
			}
		})
	})
}

function mailcious_list()
{
	//var loading = layer.load(0, {shade: false, time: 0});

	$.ajax({
		url:'handle.php',
		type: 'post',
		data: {action: 'mailcious_list'},
		dataType: 'json',
		success:function(json) {
			//layer.close(loading);
			data_update(json);
		}
	})
}

function data_update(json)
{
	var down = 0;

	var list = document.getElementById("filelist");
	while (list.rows.length > 1)
		list.deleteRow(1);
	for (i = 0; i < json.length; i++) {
		r = json[i];

		trbg = '';
		if (i % 2 == 1)
			trbg = 'log-table-tr-toggle-bgcolor-curr';

		var bps = 0;
		var istatus = '<img src="../img/10.png" width="16px" />';
		if (r.name.indexOf("tar.gz") != -1) {
			if (_lastbyte == 0)
				_lastbyte = r.size;
			bps = (r.size - _lastbyte) * 8 / sec;
			_lastbyte = r.size;
			down = 1;
			istatus = "<strong>正在下载 </strong>";
		}

		var pos = 0;
		obj = list.insertRow(-1);
		obj.setAttribute("class", trbg);

		col = obj.insertCell(pos++);
		col.setAttribute("align", "center");
		col.innerHTML = i+1;

		col = obj.insertCell(pos++);
		col.innerHTML = istatus + ' ' + r.name;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = r.size;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = r.atime;

		col = obj.insertCell(pos++);
		col.setAttribute("align", "left");
		col.innerHTML = bps;
	}
}
</script>
</body>
</html>
